@@ -58,7 +58,7 @@ AA_TABLE_REVERSED <- AA_TABLE_REVERSED[order(names(AA_TABLE_REVERSED))]
 #' 
 #' @name segments.alphabets
 #' 
-#' @aliases genealphabets HUMAN_TRAV HUMAN_TRAJ HUMAN_TRBV HUMAN_TRBD HUMAN_TRBJ HUMAN_TRBV_MITCR HUMAN_TRGV HUMAN_TRGJ HUMAN_TRDV HUMAN_TRDD HUMAN_TRDJ HUMAN_IGHV HUMAN_IGHD HUMAN_IGHJ HUMAN_IGKV HUMAN_IGKJ HUMAN_IGLJ HUMAN_IGLV HUMAN_TRBV_ALS HUMAN_TRBV_FAM HUMAN_TRBV_GEN MACMUL_TRBJ MACMUL_TRBV MOUSE_TRBJ MOUSE_TRBV
+#' @aliases genealphabets HUMAN_TRAV HUMAN_TRAJ HUMAN_TRBV HUMAN_TRBD HUMAN_TRBJ HUMAN_TRBV_MITCR HUMAN_TRGV HUMAN_TRGJ HUMAN_TRDV HUMAN_TRDD HUMAN_TRDJ HUMAN_IGHV HUMAN_IGHD HUMAN_IGHJ HUMAN_IGKV HUMAN_IGKJ HUMAN_IGLJ HUMAN_IGLV HUMAN_TRBV_ALS HUMAN_TRBV_FAM HUMAN_TRBV_GEN MACMUL_TRBJ MACMUL_TRBV MOUSE_TRBJ MOUSE_TRBV MOUSE_TRAV MOUSE_TRAJ
 #' 
 #' @usage
 #' HUMAN_TRAV
@@ -89,6 +89,10 @@ AA_TABLE_REVERSED <- AA_TABLE_REVERSED[order(names(AA_TABLE_REVERSED))]
 #' 
 #' MOUSE_TRBJ
 #' 
+#' MOUSE_TRAV
+#' 
+#' MOUSE_TRAJ
+#' 
 #' MACMUL_TRBV
 #' 
 #' MACMUL_TRBJ
@@ -206,6 +210,21 @@ HUMAN_IGLV <- c('IGLV1-36', 'IGLV1-40', 'IGLV1-41', 'IGLV1-44', 'IGLV1-47', 'IGL
                 'IGLV5-45', 'IGLV5-48', 'IGLV5-52', 'IGLV6-57', 'IGLV7-43', 'IGLV7-46', 'IGLV8-61', 'IGLV9-49')
 HUMAN_IGLJ <- c('IGLJ1', 'IGLJ2', 'IGLJ3', 'IGLJ4', 'IGLJ5', 'IGLJ6', 'IGLJ7')
 
+MOUSE_TRAV <- c('TRAV1', 'TRAV10', 'TRAV10D', 'TRAV10N', 'TRAV11', 'TRAV11D', 'TRAV11N', 'TRAV12-1', 'TRAV12-2', 'TRAV12-3', 'TRAV12D-1', 'TRAV12D-2', 
+                'TRAV12D-3', 'TRAV12N-1', 'TRAV12N-2', 'TRAV12N-3', 'TRAV13-1', 'TRAV13-2', 'TRAV13-3', 'TRAV13-4/DV7', 'TRAV13-5', 'TRAV13D-1', 
+                'TRAV13D-2', 'TRAV13D-3', 'TRAV13D-4', 'TRAV13N-1', 'TRAV13N-2', 'TRAV13N-3', 'TRAV13N-4', 'TRAV14-1', 'TRAV14-2', 'TRAV14-3', 'TRAV14D-1', 
+                'TRAV14D-2', 'TRAV14D-3/DV8', 'TRAV14N-1', 'TRAV14N-2', 'TRAV14N-3', 'TRAV15-1/DV6-1', 'TRAV15-2/DV6-2', 'TRAV15D-1/DV6D-1', 
+                'TRAV15D-2/DV6D-2', 'TRAV15N-1', 'TRAV15N-2', 'TRAV16', 'TRAV16D/DV11', 'TRAV16N', 'TRAV17', 'TRAV18', 'TRAV19', 'TRAV2', 'TRAV20', 
+                'TRAV21/DV12', 'TRAV3-1', 'TRAV3-3', 'TRAV3-4', 'TRAV3D-3', 'TRAV3N-3', 'TRAV4-2', 'TRAV4-3', 'TRAV4-4/DV10', 'TRAV4D-2', 'TRAV4D-3', 
+                'TRAV4D-4', 'TRAV4N-3', 'TRAV4N-4', 'TRAV5-1', 'TRAV5-2', 'TRAV5-4', 'TRAV5D-4', 'TRAV5N-4', 'TRAV6-1', 'TRAV6-2', 'TRAV6-3', 'TRAV6-4', 
+                'TRAV6-5', 'TRAV6-6', 'TRAV6-7/DV9', 'TRAV6D-3', 'TRAV6D-4', 'TRAV6D-5', 'TRAV6D-6', 'TRAV6D-7', 'TRAV6N-5', 'TRAV6N-6', 'TRAV6N-7', 
+                'TRAV7-1', 'TRAV7-2', 'TRAV7-3', 'TRAV7-4', 'TRAV7-5', 'TRAV7-6', 'TRAV7D-2', 'TRAV7D-3', 'TRAV7D-4', 'TRAV7D-5', 'TRAV7D-6', 'TRAV7N-4',
+                'TRAV7N-5', 'TRAV7N-6', 'TRAV8-1', 'TRAV8-2', 'TRAV8D-1', 'TRAV8D-2', 'TRAV8N-2', 'TRAV9-1', 'TRAV9-2', 'TRAV9-3', 'TRAV9-4', 'TRAV9D-1',
+                'TRAV9D-2', 'TRAV9D-3', 'TRAV9D-4', 'TRAV9N-2', 'TRAV9N-3', 'TRAV9N-4')
+MOUSE_TRAJ <- c('TRAJ11', 'TRAJ12', 'TRAJ13', 'TRAJ15', 'TRAJ16', 'TRAJ17', 'TRAJ18', 'TRAJ2', 'TRAJ21', 'TRAJ22', 'TRAJ23', 'TRAJ24', 'TRAJ26', 'TRAJ27',
+                'TRAJ28', 'TRAJ30', 'TRAJ31', 'TRAJ32', 'TRAJ33', 'TRAJ34', 'TRAJ35', 'TRAJ37', 'TRAJ38', 'TRAJ39', 'TRAJ4', 'TRAJ40', 'TRAJ42', 'TRAJ43', 'TRAJ45', 'TRAJ46', 
+                'TRAJ48', 'TRAJ49', 'TRAJ5', 'TRAJ50', 'TRAJ52', 'TRAJ53', 'TRAJ54', 'TRAJ56', 'TRAJ57', 'TRAJ58', 'TRAJ59', 'TRAJ6', 'TRAJ7', 'TRAJ9')
+
 MOUSE_TRBV <- c('TRBV1', 'TRBV12-1', 'TRBV12-2', 'TRBV13-1', 'TRBV13-2', 'TRBV13-3', 
                 'TRBV14', 'TRBV15', 'TRBV16', 'TRBV17', 'TRBV19', 'TRBV2', 'TRBV20',
                 'TRBV23', 'TRBV24', 'TRBV26', 'TRBV29', 'TRBV3', 'TRBV30', 'TRBV31', 
